# ufwio 

This is a simple package for making lmdbs for ufwio. It is a simple wrapper around the `ufwio` package.


## Installation

```bash
pip install ufwio
```

<!-- python3 -m pip install --user --upgrade twine -->
<!-- setuptools wheel -->
<!-- python3 setup.py sdist bdist_wheel -->
<!-- twine upload dist/* -->